@@ -7,6 +7,7 @@ pub mod config_update_program_fee;
 pub mod config_update_worker_fee;
 pub mod daemon_create;
 pub mod daemon_invoke;
+pub mod daemon_widthdraw;
 pub mod fee_collect;
 pub mod health_check;
 pub mod initialize;
@@ -23,6 +24,7 @@ pub use config_update_program_fee::*;
 pub use config_update_worker_fee::*;
 pub use daemon_create::*;
 pub use daemon_invoke::*;
+pub use daemon_widthdraw::*;
 pub use fee_collect::*;
 pub use health_check::*;
 pub use initialize::*;
